@@ -20,11 +20,12 @@ from neutron_lib.api import extensions
 from neutron_lib.api import validators as validators
 from neutron_lib.db import constants as db_const
 from neutron_lib import exceptions as nexception
+from neutron_lib.plugins import constants as nconstants
+from neutron_lib.services import base as service_base
+
 import six
 
 from neutron.api.v2 import resource_helper
-from neutron.plugins.common import constants as nconstants
-from neutron.services import service_base
 
 from neutron_vpnaas._i18n import _
 
