@@ -18,7 +18,6 @@ import filecmp
 import os
 import re
 import shutil
-import six
 import socket
 
 import eventlet
@@ -28,17 +27,20 @@ from neutron.agent.linux import ip_lib
 from neutron.agent.linux import utils as agent_utils
 from neutron.common import rpc as n_rpc
 from neutron.common import utils as n_utils
-from neutron import context
-from neutron.plugins.common import constants
 from neutron.plugins.common import utils as plugin_utils
 from neutron_lib.api import validators
+from neutron_lib import constants
+from neutron_lib import context
+from neutron_lib.utils import file as file_utils
 from oslo_concurrency import lockutils
 from oslo_config import cfg
+from oslo_log import helpers as log_helpers
 from oslo_log import log as logging
 import oslo_messaging
 from oslo_service import loopingcall
+import six
 
-from neutron_vpnaas._i18n import _, _LE, _LI, _LW
+from neutron_vpnaas._i18n import _
 from neutron_vpnaas.extensions import vpnaas
 from neutron_vpnaas.services.vpn.common import topics
 from neutron_vpnaas.services.vpn import device_drivers
@@ -221,9 +223,9 @@ class BaseSwanProcess(object):
         config_str = self._gen_config_content(template, vpnservice)
         config_file_name = self._get_config_filename(kind)
         if file_mode is None:
-            n_utils.replace_file(config_file_name, config_str)
+            file_utils.replace_file(config_file_name, config_str)
         else:
-            n_utils.replace_file(config_file_name, config_str, file_mode)
+            file_utils.replace_file(config_file_name, config_str, file_mode)
 
     def remove_config(self):
         """Remove whole config file."""
@@ -308,7 +310,7 @@ class BaseSwanProcess(object):
                 self.start()
         except RuntimeError:
             LOG.exception(
-                _LE("Failed to enable vpn process on router %s"),
+                "Failed to enable vpn process on router %s",
                 self.id)
 
     def disable(self):
@@ -319,7 +321,7 @@ class BaseSwanProcess(object):
             self.remove_config()
         except RuntimeError:
             LOG.exception(
-                _LE("Failed to disable vpn process on router %s"),
+                "Failed to disable vpn process on router %s",
                 self.id)
 
     @abc.abstractmethod
@@ -462,16 +464,16 @@ class OpenSwanProcess(BaseSwanProcess):
                         # logging to error instead of debug because it
                         # indicates something bad has happened and this is
                         # valuable information for figuring it out.
-                        LOG.error(_LE('Process %(pid)s exists with command '
-                                  'line %(cmd_line)s.') %
+                        LOG.error('Process %(pid)s exists with command '
+                                  'line %(cmd_line)s.',
                                   {'pid': pid, 'cmd_line': cmd_line})
                         return True
 
         except IOError as e:
             # This is logged as "info" instead of error because it simply
             # means that we couldn't find the files to check on them.
-            LOG.info(_LI('Unable to find control files on startup for '
-                         'router %(router)s: %(msg)s'),
+            LOG.info('Unable to find control files on startup for '
+                     'router %(router)s: %(msg)s',
                      {'router': self.id, 'msg': e})
         return False
 
@@ -489,8 +491,8 @@ class OpenSwanProcess(BaseSwanProcess):
                 os.remove(ctl_file)
 
         except OSError as e:
-            LOG.error(_LE('Unable to remove pluto control '
-                          'files for router %(router)s. %(msg)s'),
+            LOG.error('Unable to remove pluto control '
+                      'files for router %(router)s. %(msg)s',
                       {'router': self.id, 'msg': e})
 
     def get_status(self):
@@ -539,8 +541,8 @@ class OpenSwanProcess(BaseSwanProcess):
             eventlet.sleep(wait_interval)
             wait_interval *= cfg.CONF.pluto.shutdown_check_back_off
         else:
-            LOG.warning(_LW('Server appears to still be running, restart '
-                            'of router %s may fail'), self.id)
+            LOG.warning('Server appears to still be running, restart '
+                        'of router %s may fail', self.id)
         self.start()
         return
 
@@ -552,7 +554,7 @@ class OpenSwanProcess(BaseSwanProcess):
             addrinfo = socket.getaddrinfo(fqdn, None)[0]
             return addrinfo[-1][0]
         except socket.gaierror:
-            LOG.exception(_LE("Peer address %s cannot be resolved"), fqdn)
+            LOG.exception("Peer address %s cannot be resolved", fqdn)
 
     def _get_nexthop(self, address, connection_id):
         # check if address is an ip address or fqdn
@@ -710,10 +712,12 @@ class OpenSwanProcess(BaseSwanProcess):
 class IPsecVpnDriverApi(object):
     """IPSecVpnDriver RPC api."""
 
+    @log_helpers.log_method_call
     def __init__(self, topic):
         target = oslo_messaging.Target(topic=topic, version='1.0')
         self.client = n_rpc.get_client(target)
 
+    @log_helpers.log_method_call
     def get_vpn_services_on_host(self, context, host):
         """Get list of vpnservices.
 
@@ -723,6 +727,7 @@ class IPsecVpnDriverApi(object):
         cctxt = self.client.prepare()
         return cctxt.call(context, 'get_vpn_services_on_host', host=host)
 
+    @log_helpers.log_method_call
     def update_status(self, context, status):
         """Update local status.
 
@@ -873,6 +878,7 @@ class IPsecDriver(device_drivers.DeviceDriver):
                          top=True)
         self.iptables_apply(router_id)
 
+    @log_helpers.log_method_call
     def vpnservice_updated(self, context, **kwargs):
         """Vpnservice updated rpc handler
 
@@ -999,6 +1005,7 @@ class IPsecDriver(device_drivers.DeviceDriver):
             process.vpnservice["tenant_id"] == context.tenant_id):
             return True
 
+    @log_helpers.log_method_call
     def report_status(self, context):
         status_changed_vpn_services = []
         for process in self.processes.values():
@@ -1020,6 +1027,7 @@ class IPsecDriver(device_drivers.DeviceDriver):
                 context,
                 status_changed_vpn_services)
 
+    @log_helpers.log_method_call
     @lockutils.synchronized('vpn-agent', 'neutron-')
     def sync(self, context, routers):
         """Sync status with server side.
