@@ -12,7 +12,6 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from neutron_vpnaas._i18n import _LI
 from rally.common import logging
 from rally.task import scenario
 from rally.task import types as types
@@ -63,7 +62,7 @@ class TestVpnBasicScenario(vpn_base.VpnBase):
             self.create_ipsec_site_connections(**kwargs)
             self.assert_statuses(final_status='ACTIVE', **kwargs)
             self.verify_vpn_connectivity(**kwargs)
-            LOG.info(_LI("VPN CONNECTIVITY TEST PASSED!"))
+            LOG.info("VPN CONNECTIVITY TEST PASSED!")
 
         finally:
             self.cleanup()
